summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSebastien Helleu <flashcode@flashtux.org>2009-04-24 17:24:56 +0200
committerSebastien Helleu <flashcode@flashtux.org>2009-04-24 17:24:56 +0200
commite3d2728571be0b56dc67253137366d96e3e7282a (patch)
tree298f5f9896373ac2a73c2eb61e38eae43eb72a17
parent3464865a000c70b54bc9332d66944855294a128f (diff)
downloadweechat-e3d2728571be0b56dc67253137366d96e3e7282a.zip
Fix typo: splited/splitted -> split
-rw-r--r--ChangeLog8
-rw-r--r--doc/de/autogen/weechat_options.xml2
-rw-r--r--doc/de/dev/plugin_c_api.de.xml14
-rw-r--r--doc/en/autogen/weechat_options.xml2
-rw-r--r--doc/en/dev/plugin_c_api.en.xml14
-rw-r--r--doc/en/weechat_quickstart.en.txt2
-rw-r--r--doc/fr/dev/plugin_c_api.fr.xml14
-rw-r--r--po/cs.po4
-rw-r--r--po/de.po4
-rw-r--r--po/es.po4
-rw-r--r--po/fr.po6
-rw-r--r--po/hu.po4
-rw-r--r--po/ru.po4
-rw-r--r--po/weechat.pot4
-rw-r--r--src/core/wee-command.c2
-rw-r--r--src/core/wee-config.c2
-rw-r--r--src/core/wee-string.c14
-rw-r--r--src/core/wee-string.h2
-rw-r--r--src/gui/curses/gui-curses.h2
-rw-r--r--src/gui/gui-bar-window.c40
-rw-r--r--src/gui/gui-keyboard.c2
-rw-r--r--src/plugins/alias/alias.c2
-rw-r--r--src/plugins/irc/irc-protocol.c2
-rw-r--r--src/plugins/plugin.c2
-rw-r--r--src/plugins/trigger/trigger-libc.c2
-rw-r--r--src/plugins/weechat-plugin.h6
26 files changed, 82 insertions, 82 deletions
diff --git a/ChangeLog b/ChangeLog
index 57273585a..0ca03c912 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -222,7 +222,7 @@ Version 0.2.2 (2007-01-06):
* add keys (F9/F10) to scroll topic (task #6030)
* add auto completion with channels and filenames (task #5423)
* fix memleak in keyboard input
- * fix refresh bug when changing config options if window is splited
+ * fix refresh bug when changing config options if window is split
* add space between chat and nicklist when position is "right" (bug #17852)
* add option "look_nicklist_separator" (task #5437)
* fix bug with DCC SEND when filename begins with '~'
@@ -311,7 +311,7 @@ Version 0.2.0 (2006-08-19):
* fix random crash when "MODE #chan -l" is received
* fix bug in IRC parser (random crash with malformed IRC messages)
* fix refresh bugs when terminal is resized: too many refreshs,
- display bug with splited windows
+ display bug with split windows
* case ignored for channel names in charset options (bug #16858)
* fix crash when setting look_one_server_buffer to ON (bug #16932)
* add new functions in plugin/script API: get window info,
@@ -326,7 +326,7 @@ Version 0.2.0 (2006-08-19):
* fix bug with connection to bnc (bug #16760)
* command /save now writes plugins options (~/.weechat/plugins.rc)
* fix crash with "register" function in plugin scripts (bug #16701)
- * fix random crash at exit (/quit or /upgrade) with splited windows
+ * fix random crash at exit (/quit or /upgrade) with split windows
Version 0.1.9 (2006-05-25):
* fix /squery command (message sent to server, now ok with # args > 2)
@@ -430,7 +430,7 @@ Version 0.1.7 (2006-01-14):
new values for "irc_display_away" (off, local, channel)
* fix refresh bug with Solaris when term size is changed
* replace Texinfo doc by XML Docbook
- * add color for window separators (when splited)
+ * add color for window separators (when split)
* add completion system for plugins/scripts commands
* fix plugins autoload
* add charset by server and channel, new command: /charset
diff --git a/doc/de/autogen/weechat_options.xml b/doc/de/autogen/weechat_options.xml
index 67df5783d..c67f3d06e 100644
--- a/doc/de/autogen/weechat_options.xml
+++ b/doc/de/autogen/weechat_options.xml
@@ -496,7 +496,7 @@
</listitem>
</itemizedlist>
-<command>weechat.color.separator</command>: background color for window separators (when splitted)
+<command>weechat.color.separator</command>: background color for window separators (when split)
<itemizedlist>
<listitem>
<para>type: color</para>
diff --git a/doc/de/dev/plugin_c_api.de.xml b/doc/de/dev/plugin_c_api.de.xml
index 14577d71d..f35947871 100644
--- a/doc/de/dev/plugin_c_api.de.xml
+++ b/doc/de/dev/plugin_c_api.de.xml
@@ -1006,7 +1006,7 @@ char **weechat_string_split_command (const char *command, char separator);
<note>
<para>
Result has to be free by a call to
- "weechat_string_free_splitted_command" after use.
+ "weechat_string_free_split_command" after use.
</para>
</note>
<para>
@@ -1015,24 +1015,24 @@ char **weechat_string_split_command (const char *command, char separator);
</para>
</section>
- <section id="secPluginCApi_weechat_string_splitted_command">
- <title>weechat_string_free_splitted_command</title>
+ <section id="secPluginCApi_weechat_string_split_command">
+ <title>weechat_string_free_split_command</title>
<para>
Prototype:
<programlisting>
-void weechat_string_free_splitted_command (char **splitted_command);
+void weechat_string_free_split_command (char **split_command);
</programlisting>
</para>
<para>
- Free memory used by a splitted command.
+ Free memory used by a split command.
</para>
<para>
Arguments:
<itemizedlist>
<listitem>
<para>
- <option>splitted_command</option>: command splitted by
+ <option>split_command</option>: command split by
"weechat_string_split_commaand" function
</para>
</listitem>
@@ -1046,7 +1046,7 @@ void weechat_string_free_splitted_command (char **splitted_command);
<screen>
char **argv = weechat_string_split_command ("/command1;/command2", ';');
...
-weechat_string_free_splitted_command (argv);
+weechat_string_free_split_command (argv);
</screen>
</para>
</section>
diff --git a/doc/en/autogen/weechat_options.xml b/doc/en/autogen/weechat_options.xml
index 2cb331b86..8801ca7d0 100644
--- a/doc/en/autogen/weechat_options.xml
+++ b/doc/en/autogen/weechat_options.xml
@@ -496,7 +496,7 @@
</listitem>
</itemizedlist>
-<command>weechat.color.separator</command>: background color for window separators (when splitted)
+<command>weechat.color.separator</command>: background color for window separators (when split)
<itemizedlist>
<listitem>
<para>type: color</para>
diff --git a/doc/en/dev/plugin_c_api.en.xml b/doc/en/dev/plugin_c_api.en.xml
index 9b668e6f3..211163bdf 100644
--- a/doc/en/dev/plugin_c_api.en.xml
+++ b/doc/en/dev/plugin_c_api.en.xml
@@ -1005,7 +1005,7 @@ char **weechat_string_split_command (const char *command, char separator);
<note>
<para>
Result has to be free by a call to
- "weechat_string_free_splitted_command" after use.
+ "weechat_string_free_split_command" after use.
</para>
</note>
<para>
@@ -1014,24 +1014,24 @@ char **weechat_string_split_command (const char *command, char separator);
</para>
</section>
- <section id="secPluginCApi_weechat_string_splitted_command">
- <title>weechat_string_free_splitted_command</title>
+ <section id="secPluginCApi_weechat_string_split_command">
+ <title>weechat_string_free_split_command</title>
<para>
Prototype:
<programlisting>
-void weechat_string_free_splitted_command (char **splitted_command);
+void weechat_string_free_split_command (char **split_command);
</programlisting>
</para>
<para>
- Free memory used by a splitted command.
+ Free memory used by a split command.
</para>
<para>
Arguments:
<itemizedlist>
<listitem>
<para>
- <option>splitted_command</option>: command splitted by
+ <option>split_command</option>: command split by
"weechat_string_split_commaand" function
</para>
</listitem>
@@ -1045,7 +1045,7 @@ void weechat_string_free_splitted_command (char **splitted_command);
<screen>
char **argv = weechat_string_split_command ("/command1;/command2", ';');
...
-weechat_string_free_splitted_command (argv);
+weechat_string_free_split_command (argv);
</screen>
</para>
</section>
diff --git a/doc/en/weechat_quickstart.en.txt b/doc/en/weechat_quickstart.en.txt
index 611137508..065d4cfac 100644
--- a/doc/en/weechat_quickstart.en.txt
+++ b/doc/en/weechat_quickstart.en.txt
@@ -155,7 +155,7 @@ WeeChat quick start guide (english version, for WeeChat >= 0.2.7)
WeeChat uses many keys by default. All these keys are in documentation,
but you should know at least some vital keys:
- alt + left/right arrows (or F5/F6): switch to previous/next buffer
- - F7/F8: switch to previous/next window (when screen is splited)
+ - F7/F8: switch to previous/next window (when screen is split)
- F9/F10: scroll title bar
- F11/F12: scroll nicklist
- tab: complete text in input bar, like in your shell
diff --git a/doc/fr/dev/plugin_c_api.fr.xml b/doc/fr/dev/plugin_c_api.fr.xml
index a7f41af52..0c00862ff 100644
--- a/doc/fr/dev/plugin_c_api.fr.xml
+++ b/doc/fr/dev/plugin_c_api.fr.xml
@@ -1006,7 +1006,7 @@ char **weechat_string_split_command (const char *command, char separator);
<note>
<para>
Result has to be free by a call to
- "weechat_string_free_splitted_command" after use.
+ "weechat_string_free_split_command" after use.
</para>
</note>
<para>
@@ -1015,24 +1015,24 @@ char **weechat_string_split_command (const char *command, char separator);
</para>
</section>
- <section id="secPluginCApi_weechat_string_splitted_command">
- <title>weechat_string_free_splitted_command</title>
+ <section id="secPluginCApi_weechat_string_split_command">
+ <title>weechat_string_free_split_command</title>
<para>
Prototype:
<programlisting>
-void weechat_string_free_splitted_command (char **splitted_command);
+void weechat_string_free_split_command (char **split_command);
</programlisting>
</para>
<para>
- Free memory used by a splitted command.
+ Free memory used by a split command.
</para>
<para>
Arguments:
<itemizedlist>
<listitem>
<para>
- <option>splitted_command</option>: command splitted by
+ <option>split_command</option>: command split by
"weechat_string_split_commaand" function
</para>
</listitem>
@@ -1046,7 +1046,7 @@ void weechat_string_free_splitted_command (char **splitted_command);
<screen>
char **argv = weechat_string_split_command ("/command1;/command2", ';');
...
-weechat_string_free_splitted_command (argv);
+weechat_string_free_split_command (argv);
</screen>
</para>
</section>
diff --git a/po/cs.po b/po/cs.po
index 3b6677ccb..d373f3cbc 100644
--- a/po/cs.po
+++ b/po/cs.po
@@ -6,7 +6,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.2.7-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-04-24 17:04+0200\n"
+"POT-Creation-Date: 2009-04-24 17:16+0200\n"
"PO-Revision-Date: 2009-01-03 00:42+0100\n"
"Last-Translator: Jiri Golembiovsky <golemj@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1414,7 +1414,7 @@ msgid "set title for window (terminal for Curses GUI) with name and version"
msgstr "nastaví titulek okna (terminálu pro Cruses GUI) s jménem a verzí"
#, fuzzy
-msgid "background color for window separators (when splitted)"
+msgid "background color for window separators (when split)"
msgstr "barva děliče oken (při rozdělení)"
#, fuzzy
diff --git a/po/de.po b/po/de.po
index aee6c7b3f..41c7151b8 100644
--- a/po/de.po
+++ b/po/de.po
@@ -9,7 +9,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.2.7-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-04-24 17:04+0200\n"
+"POT-Creation-Date: 2009-04-24 17:16+0200\n"
"PO-Revision-Date: 2009-01-03 00:42+0100\n"
"Last-Translator: Thomas Schuetz <i18n@internet-villa.de>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1437,7 +1437,7 @@ msgstr ""
"Fenstertitel setzen (oder Terminaltitel im Curses-GUI) mit Name und Version"
#, fuzzy
-msgid "background color for window separators (when splitted)"
+msgid "background color for window separators (when split)"
msgstr ""
"Farbe der Fenster-Separatoren im Chatfenster (bei geteiltem Bildschirm)"
diff --git a/po/es.po b/po/es.po
index 4314fbe94..37f0035f2 100644
--- a/po/es.po
+++ b/po/es.po
@@ -6,7 +6,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.2.7-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-04-24 17:04+0200\n"
+"POT-Creation-Date: 2009-04-24 17:16+0200\n"
"PO-Revision-Date: 2009-01-03 00:42+0100\n"
"Last-Translator: Roberto González Cardenete <robert.glez@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1419,7 +1419,7 @@ msgstr ""
"nombre y la versión"
#, fuzzy
-msgid "background color for window separators (when splitted)"
+msgid "background color for window separators (when split)"
msgstr "color para los separadores de ventana (cuando se dividen)"
#, fuzzy
diff --git a/po/fr.po b/po/fr.po
index 9a5d03a94..de3d493ad 100644
--- a/po/fr.po
+++ b/po/fr.po
@@ -6,8 +6,8 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.2.7-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-04-24 17:04+0200\n"
-"PO-Revision-Date: 2009-04-24 17:05+0200\n"
+"POT-Creation-Date: 2009-04-24 17:16+0200\n"
+"PO-Revision-Date: 2009-04-24 17:16+0200\n"
"Last-Translator: FlashCode <flashcode@flashtux.org>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
"MIME-Version: 1.0\n"
@@ -1551,7 +1551,7 @@ msgstr ""
"définit le titre de la fenêtre (terminal pour l'interface Curses) avec le "
"nom et la version"
-msgid "background color for window separators (when splitted)"
+msgid "background color for window separators (when split)"
msgstr "couleur du fond pour les séparateurs de fenêtres (quand divisé)"
msgid "text color for '+' when scrolling bars"
diff --git a/po/hu.po b/po/hu.po
index 61150bb3e..f3e78d85b 100644
--- a/po/hu.po
+++ b/po/hu.po
@@ -12,7 +12,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.2.7-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-04-24 17:04+0200\n"
+"POT-Creation-Date: 2009-04-24 17:16+0200\n"
"PO-Revision-Date: 2009-01-03 00:42+0100\n"
"Last-Translator: Andras Voroskoi <voroskoi@frugalware.org>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1448,7 +1448,7 @@ msgstr ""
"és verziójára"
#, fuzzy
-msgid "background color for window separators (when splitted)"
+msgid "background color for window separators (when split)"
msgstr "ablakelválasztó színe (ha meg van osztva)"
#, fuzzy
diff --git a/po/ru.po b/po/ru.po
index 36dcc294c..cb74d0bab 100644
--- a/po/ru.po
+++ b/po/ru.po
@@ -6,7 +6,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.2.7-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-04-24 17:04+0200\n"
+"POT-Creation-Date: 2009-04-24 17:16+0200\n"
"PO-Revision-Date: 2009-01-03 00:42+0100\n"
"Last-Translator: Pavel Shevchuk <stlwrt@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1451,7 +1451,7 @@ msgstr ""
"версией"
#, fuzzy
-msgid "background color for window separators (when splitted)"
+msgid "background color for window separators (when split)"
msgstr "цвет разделителей окна (при разбитом экране)"
#, fuzzy
diff --git a/po/weechat.pot b/po/weechat.pot
index 651404aba..40876a324 100644
--- a/po/weechat.pot
+++ b/po/weechat.pot
@@ -7,7 +7,7 @@ msgid ""
msgstr ""
"Project-Id-Version: PACKAGE VERSION\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-04-24 17:04+0200\n"
+"POT-Creation-Date: 2009-04-24 17:16+0200\n"
"PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
"Language-Team: LANGUAGE <LL@li.org>\n"
@@ -1233,7 +1233,7 @@ msgstr ""
msgid "set title for window (terminal for Curses GUI) with name and version"
msgstr ""
-msgid "background color for window separators (when splitted)"
+msgid "background color for window separators (when split)"
msgstr ""
msgid "text color for '+' when scrolling bars"
diff --git a/src/core/wee-command.c b/src/core/wee-command.c
index a67dc8b60..6beb4c185 100644
--- a/src/core/wee-command.c
+++ b/src/core/wee-command.c
@@ -4033,7 +4033,7 @@ command_startup (int plugins_loaded)
{
input_data (weechat_buffer, *ptr_cmd);
}
- string_free_splitted_command (commands);
+ string_free_split_command (commands);
}
}
}
diff --git a/src/core/wee-config.c b/src/core/wee-config.c
index 44522dbde..7d65d16d3 100644
--- a/src/core/wee-config.c
+++ b/src/core/wee-config.c
@@ -1409,7 +1409,7 @@ config_weechat_init_options ()
config_color_separator = config_file_new_option (
weechat_config_file, ptr_section,
"separator", "color",
- N_("background color for window separators (when splitted)"),
+ N_("background color for window separators (when split)"),
NULL, GUI_COLOR_SEPARATOR, 0, "blue", NULL, 0,
NULL, NULL, &config_change_color, NULL, NULL, NULL);
/* bar colors */
diff --git a/src/core/wee-string.h b/src/core/wee-string.h
index b4dde55d9..7acbe3dc6 100644
--- a/src/core/wee-string.h
+++ b/src/core/wee-string.h
@@ -48,7 +48,7 @@ extern void string_free_exploded (char **exploded_string);
extern char *string_build_with_exploded (const char **exploded_string,
const char *separator);
extern char **string_split_command (const char *command, char separator);
-extern void string_free_splitted_command (char **splitted_command);
+extern void string_free_split_command (char **split_command);
extern char *string_iconv (int from_utf8, const char *from_code,
const char *to_code, const char *string);
extern char *string_iconv_to_internal (const char *charset, const char *string);
diff --git a/src/gui/curses/gui-curses.h b/src/gui/curses/gui-curses.h
index 6ec8910c9..a5125c0d3 100644
--- a/src/gui/curses/gui-curses.h
+++ b/src/gui/curses/gui-curses.h
@@ -42,7 +42,7 @@ struct t_gui_bar_window;
struct t_gui_window_curses_objects
{
WINDOW *win_chat; /* chat window (example: channel) */
- WINDOW *win_separator; /* separation between 2 splitted (V) win*/
+ WINDOW *win_separator; /* separation between 2 split (V) win */
};
struct t_gui_bar_window_curses_objects
diff --git a/src/gui/gui-keyboard.c b/src/gui/gui-keyboard.c
index a24c03642..a8c9bbd29 100644
--- a/src/gui/gui-keyboard.c
+++ b/src/gui/gui-keyboard.c
@@ -504,7 +504,7 @@ gui_keyboard_pressed (const char *key_str)
input_data (gui_current_window->buffer,
*ptr_cmd);
}
- string_free_splitted_command (commands);
+ string_free_split_command (commands);
}
}
diff --git a/src/plugins/alias/alias.c b/src/plugins/alias/alias.c
index 53e724fcd..ab0dcdc40 100644
--- a/src/plugins/alias/alias.c
+++ b/src/plugins/alias/alias.c
@@ -344,7 +344,7 @@ alias_cb (void *data, struct t_gui_buffer *buffer, int argc, char **argv,
}
}
ptr_alias->running = 0;
- weechat_string_free_splitted_command (commands);
+ weechat_string_free_split_command (commands);
}
}
return WEECHAT_RC_OK;
diff --git a/src/plugins/irc/irc-protocol.c b/src/plugins/irc/irc-protocol.c
index 1b64213e5..da0ff823b 100644
--- a/src/plugins/irc/irc-protocol.c
+++ b/src/plugins/irc/irc-protocol.c
@@ -2473,7 +2473,7 @@ irc_protocol_cmd_001 (struct t_irc_server *server, const char *command,
if (vars_replaced)
free (vars_replaced);
}
- weechat_string_free_splitted_command (commands);
+ weechat_string_free_split_command (commands);
}
if (IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_COMMAND_DELAY) > 0)
diff --git a/src/plugins/plugin.c b/src/plugins/plugin.c
index 7fbd320ce..96407749f 100644
--- a/src/plugins/plugin.c
+++ b/src/plugins/plugin.c
@@ -368,7 +368,7 @@ plugin_load (const char *filename)
new_plugin->string_free_exploded = &string_free_exploded;
new_plugin->string_build_with_exploded = &string_build_with_exploded;
new_plugin->string_split_command = &string_split_command;
- new_plugin->string_free_splitted_command = &string_free_splitted_command;
+ new_plugin->string_free_split_command = &string_free_split_command;
new_plugin->string_format_size = &string_format_size;
new_plugin->string_remove_color = &gui_color_decode;
diff --git a/src/plugins/trigger/trigger-libc.c b/src/plugins/trigger/trigger-libc.c
index 0de18da4a..f0dcbe70a 100644
--- a/src/plugins/trigger/trigger-libc.c
+++ b/src/plugins/trigger/trigger-libc.c
@@ -367,7 +367,7 @@ c_split_multi_command (char *command, char sep)
}
/*
- * c_free_multi_command : free a list of commands splitted
+ * c_free_multi_command : free a list of commands split
* with split_multi_command
*/
diff --git a/src/plugins/weechat-plugin.h b/src/plugins/weechat-plugin.h
index 059100482..19bfd25ae 100644
--- a/src/plugins/weechat-plugin.h
+++ b/src/plugins/weechat-plugin.h
@@ -165,7 +165,7 @@ struct t_weechat_plugin
char *(*string_build_with_exploded) (const char **exploded_string,
const char *separator);
char **(*string_split_command) (const char *command, char separator);
- void (*string_free_splitted_command) (char **splitted_command);
+ void (*string_free_split_command) (char **split_command);
char *(*string_format_size) (unsigned long size);
char *(*string_remove_color) (const char *string, const char *replacement);
@@ -695,8 +695,8 @@ extern int weechat_plugin_end (struct t_weechat_plugin *plugin);
__separator)
#define weechat_string_split_command(__command, __separator) \
weechat_plugin->string_split_command(__command, __separator)
-#define weechat_string_free_splitted_command(__splitted_command) \
- weechat_plugin->string_free_splitted_command(__splitted_command)
+#define weechat_string_free_split_command(__split_command) \
+ weechat_plugin->string_free_split_command(__split_command)
#define weechat_string_format_size(__size) \
weechat_plugin->string_format_size(__size)
#define weechat_string_remove_color(__string, __replacement) \
diff --git a/src/core/wee-string.c b/src/core/wee-string.c
index 9a438f456..02be5fd4b 100644
--- a/src/core/wee-string.c
+++ b/src/core/wee-string.c
@@ -1008,20 +1008,20 @@ string_split_command (const char *command, char separator)
}
/*
* string_free_splitted_command : free a list of commands splitted
* with string_split_command
*/
void
-string_free_splitted_command (char **splitted_command)
+string_free_split_command (char **split_command)
{
int i;
- if (splitted_command)
+ if (split_command)
{
- for (i = 0; splitted_command[i]; i++)
- free (splitted_command[i]);
- free (splitted_command);
+ for (i = 0; split_command[i]; i++)
+ free (split_command[i]);
+ free (split_command);
}
}
@@ -1008,20 +1008,20 @@ string_split_command (const char *command, char separator)
}
/*
- * string_free_splitted_command : free a list of commands splitted
- * with string_split_command
+ * string_free_split_command : free a list of commands split
+ * with string_split_command
*/
void
diff --git a/src/gui/gui-bar-window.c b/src/gui/gui-bar-window.c
index f6b1ddc23..978fb3511 100644
--- a/src/gui/gui-bar-window.c
+++ b/src/gui/gui-bar-window.c
@@ -436,7 +436,7 @@ gui_bar_window_content_get_with_filling (struct t_gui_bar_window *bar_window,
{
enum t_gui_bar_filling filling;
char *ptr_content, *content, reinit_color[32], reinit_color_space[32];
- char *item_value, ****splitted_items, **linear_items;
+ char *item_value, ****split_items, **linear_items;
int index_content, content_length, i, sub, j, k, index;
int length_reinit_color, length_reinit_color_space;
int length, max_length, max_length_screen, total_items, columns, lines;
@@ -521,39 +521,39 @@ gui_bar_window_content_get_with_filling (struct t_gui_bar_window *bar_window,
total_items = 0;
max_length = 1;
max_length_screen = 1;
- splitted_items = malloc(bar_window->items_count * sizeof(*splitted_items));
+ split_items = malloc(bar_window->items_count * sizeof(*split_items));
for (i = 0; i < bar_window->items_count; i++)
{
if (bar_window->items_subcount[i] > 0)
{
- splitted_items[i] = malloc (bar_window->items_subcount[i] * sizeof (**splitted_items));
+ split_items[i] = malloc (bar_window->items_subcount[i] * sizeof (**split_items));
for (sub = 0; sub < bar_window->items_subcount[i]; sub++)
{
ptr_content = gui_bar_window_content_get (bar_window, window,
i, sub);
if (ptr_content && ptr_content[0])
{
- splitted_items[i][sub] = string_explode (ptr_content,
- "\n", 0, 0, NULL);
- for (j = 0; splitted_items[i][sub][j]; j++)
+ split_items[i][sub] = string_explode (ptr_content,
+ "\n", 0, 0, NULL);
+ for (j = 0; split_items[i][sub][j]; j++)
{
total_items++;
- length = strlen (splitted_items[i][sub][j]);
+ length = strlen (split_items[i][sub][j]);
if (length > max_length)
max_length = length;
- length = gui_chat_strlen_screen (splitted_items[i][sub][j]);
+ length = gui_chat_strlen_screen (split_items[i][sub][j]);
if (length > max_length_screen)
max_length_screen = length;
}
}
else
- splitted_items[i] = NULL;
+ split_items[i] = NULL;
}
}
else
- splitted_items[i] = NULL;
+ split_items[i] = NULL;
}
if ((CONFIG_INTEGER(bar_window->bar->options[GUI_BAR_OPTION_POSITION]) == GUI_BAR_POSITION_BOTTOM)
|| (CONFIG_INTEGER(bar_window->bar->options[GUI_BAR_OPTION_POSITION]) == GUI_BAR_POSITION_TOP))
@@ -573,7 +573,7 @@ gui_bar_window_content_get_with_filling (struct t_gui_bar_window *bar_window,
lines = bar_window->height;
}
/* build array with pointers to splitted items */
linear_items = malloc (total_items * sizeof (*linear_items));
if (linear_items)
@@ -581,15 +581,15 @@ gui_bar_window_content_get_with_filling (struct t_gui_bar_window *bar_window,
index = 0;
for (i = 0; i < bar_window->items_count; i++)
{
- if (splitted_items[i])
+ if (split_items[i])
{
for (sub = 0; sub < bar_window->items_subcount[i]; sub++)
{
- if (splitted_items[i][sub])
+ if (split_items[i][sub])
{
- for (j = 0; splitted_items[i][sub][j]; j++)
+ for (j = 0; split_items[i][sub][j]; j++)
{
- linear_items[index++] = splitted_items[i][sub][j];
+ linear_items[index++] = split_items[i][sub][j];
}
}
}
@@ -647,17 +647,17 @@ gui_bar_window_content_get_with_filling (struct t_gui_bar_window *bar_window,
for (i = 0; i < bar_window->items_count; i++)
{
- if (splitted_items[i])
+ if (split_items[i])
{
for (sub = 0; sub < bar_window->items_subcount[i]; sub++)
{
- if (splitted_items[i][sub])
- string_free_exploded (splitted_items[i][sub]);
+ if (split_items[i][sub])
+ string_free_exploded (split_items[i][sub]);
}
- free (splitted_items[i]);
+ free (split_items[i]);
}
}
- free (splitted_items);
+ free (split_items);
break;
case GUI_BAR_NUM_FILLING:
break;
@@ -573,7 +573,7 @@ gui_bar_window_content_get_with_filling (struct t_gui_bar_window *bar_window,
lines = bar_window->height;
}
- /* build array with pointers to splitted items */
+ /* build array with pointers to split items */
linear_items = malloc (total_items * sizeof (*linear_items));
if (linear_items)